// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.connect.replicator;

import org.apache.commons.codec.binary.Base64;
import org.apache.kafka.clients.consumer.internals.ConsumerProtocol;
import org.apache.kafka.clients.consumer.internals.PartitionAssignor;
import org.apache.kafka.common.config.ConfigDef;
import org.apache.kafka.common.config.ConfigDef.Importance;
import org.apache.kafka.common.config.ConfigDef.Type;

import java.nio.ByteBuffer;
import java.util.HashMap;
import java.util.Map;

public class ReplicatorSourceTaskConfig extends ReplicatorSourceConnectorConfig {

  private static final String TASK_ID_CONFIG = "task.id";
  private static final String TASK_ID_DOC = "Task ID assigned by the connector (used for logging)";

  private static final String PARTITION_ASSIGNMENT_CONFIG = "partition.assignment";
  private static final String PARTITION_ASSIGNMENT_DOC = "";

  static ConfigDef config = baseConfigDef()
          .define(TASK_ID_CONFIG, Type.STRING, Importance.HIGH, TASK_ID_DOC)
          .define(PARTITION_ASSIGNMENT_CONFIG, Type.STRING, Importance.HIGH, PARTITION_ASSIGNMENT_DOC);

  public ReplicatorSourceTaskConfig(Map<String, String> parsedConfig) {
    super(config, parsedConfig);
  }

  public String getTaskId() {
    return getString(TASK_ID_CONFIG);
  }

  public PartitionAssignor.Assignment getPartitionAssignment() {
    return decodeAssignment(getString(PARTITION_ASSIGNMENT_CONFIG));
  }

  private static PartitionAssignor.Assignment decodeAssignment(String encodedAssignment) {
    // TODO: We can use JDK Base64 decoder after upgrading to Java 8 and remove commons codec
    byte[] decodedAssignment = Base64.decodeBase64(encodedAssignment);
    return ConsumerProtocol.deserializeAssignment(ByteBuffer.wrap(decodedAssignment));
  }

  private static String encodeAssignment(PartitionAssignor.Assignment assignment) {
    ByteBuffer byteBuffer = ConsumerProtocol.serializeAssignment(assignment);
    final int length = byteBuffer.remaining();
    byte[] serializedAssignment = new byte[length];
    byteBuffer.get(serializedAssignment);
    return Base64.encodeBase64String(serializedAssignment);
  }

  public static Builder builder(ReplicatorSourceConnectorConfig config) {
    return new Builder(config.originalsStrings());
  }

  public static class Builder {
    private final Map<String, String> config;

    public Builder(Map<String, String> config) {
      this.config = new HashMap<>(config);
    }

    public Builder setAssignment(PartitionAssignor.Assignment assignment) {
      this.config.put(PARTITION_ASSIGNMENT_CONFIG, encodeAssignment(assignment));
      return this;
    }

    public Builder setTaskId(String taskId) {
      this.config.put(TASK_ID_CONFIG, taskId);
      return this;
    }

    public ReplicatorSourceTaskConfig build() {
      return new ReplicatorSourceTaskConfig(config);
    }

  }

}
