// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.connect.replicator.util;

import org.jose4j.jwt.JwtClaims;
import org.jose4j.jwt.consumer.InvalidJwtException;

import java.security.PublicKey;
import java.text.SimpleDateFormat;
import java.util.Date;

import io.confluent.license.License;

public class LicenseValidation {

  public static class Failure extends Exception {
    public Failure(String message) {
      super(message);
    }

    public Failure(String message, Throwable cause) {
      super(message, cause);
    }
  }

  public static void verify(String license) throws Failure {
    final PublicKey publicKey;
    try {
      publicKey = License.loadPublicKey();
    } catch (Exception e) {
      throw new Failure("Failed to load public key", e);
    }
    verify(publicKey, license);
  }

  static void verify(PublicKey publicKey, String license) throws Failure {
    final JwtClaims jwtClaims = getJwtClaims(publicKey, license);
    final long expirationTimeMillis = License.getExpiration(jwtClaims);
    if (System.currentTimeMillis() > expirationTimeMillis) {
      final SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
      throw new Failure("Expired as of " + dateFormat.format(new Date(expirationTimeMillis)));
    }
  }

  private static JwtClaims getJwtClaims(PublicKey publicKey, String licenseStr) throws Failure {
    final JwtClaims jwtClaims;
    try {
      jwtClaims = License.verify(publicKey, licenseStr);
    } catch (InvalidJwtException e) {
      throw new Failure(String.format("Could not verify '%s'", licenseStr), e);
    }
    return jwtClaims;
  }

}
