// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.connect.replicator.util;

import org.I0Itec.zkclient.exception.ZkNodeExistsException;
import org.apache.zookeeper.data.Stat;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.concurrent.TimeUnit;

import kafka.utils.ZkUtils;

public class TrialPeriod {

  private static final Logger log = LoggerFactory.getLogger(TrialPeriod.class);

  static final String ZK_PATH = "/confluent-replicator";
  static final long TRIAL_LIMIT_MILLIS = TimeUnit.DAYS.toMillis(30);
  static final long WARN_THRESHOLD_MILLIS = TimeUnit.DAYS.toMillis(5);

  public static boolean startOrVerify(long currentTimeMillis, ZkUtils zkUtils) {
    try {
      zkUtils.createPersistentPath(ZK_PATH, "", zkUtils.DefaultAcls());
      return true;
    } catch (ZkNodeExistsException ignored) {
      // Trial already started
    }

    final Stat stat = zkUtils.readData(ZK_PATH)._2();
    final long elapsedMillis = Math.max(0, currentTimeMillis - stat.getCtime());
    final long remainingMillis = TRIAL_LIMIT_MILLIS - elapsedMillis;
    if (remainingMillis < 0) {
      log.error("Trial expired since {} days", TimeUnit.MILLISECONDS.toDays(-1 * remainingMillis));
      return false;
    } else if (remainingMillis < WARN_THRESHOLD_MILLIS) {
      log.warn("Remaining trial period: {} days", TimeUnit.MILLISECONDS.toDays(remainingMillis));
      return false;
    } else {
      log.info("Remaining trial period: {} days", TimeUnit.MILLISECONDS.toDays(remainingMillis));
      return true;
    }
  }

}
