// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.connect.replicator.util;

import org.apache.kafka.common.TopicPartition;
import org.apache.kafka.connect.errors.ConnectException;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.regex.Pattern;

public class Utils {

  private static final Pattern LEGAL_TOPIC_NAME_PATTERN = Pattern.compile("[a-zA-Z0-9\\._\\-]+");

  private Utils() {}

  public static Map<String, ?> toConnectPartition(TopicPartition topicPartition) {
    return toConnectPartition(topicPartition.topic(), topicPartition.partition());
  }

  public static Map<String, Object> toConnectOffset(long offset) {
    return Collections.<String, Object>singletonMap("offset", offset);
  }

  public static Map<String, ?> toConnectPartition(String topic, int partition) {
    Map<String, Object> connectPartition = new HashMap<>(2);
    connectPartition.put("topic", topic);
    connectPartition.put("partition", partition);
    return connectPartition;
  }

  public static String renameTopic(String renameFormat, String topic) {
    String renamed = renameFormat.replace("${topic}", topic);
    if (!LEGAL_TOPIC_NAME_PATTERN.matcher(renamed).matches())
      throw new ConnectException("Illegal topic name '" + renamed + "' after applying rename format to topic '" + topic + "'");
    return renamed;
  }

  /**
   * Get the minimum among multiple nullable deadlines (i.e. timestamps).
   * @param deadlines nullable deadlines
   * @return the minimum among several deadlines or Long.MAX_VALUE if all are null
   */
  public static long nextDeadline(Long... deadlines) {
    long nextDeadline = Long.MAX_VALUE;
    for (Long next : deadlines) {
      if (next != null)
        nextDeadline = Math.min(nextDeadline, next);
    }

    return nextDeadline;
  }

}
