// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.connect.replicator;

import org.apache.kafka.common.config.ConfigException;
import org.apache.kafka.common.record.TimestampType;
import org.junit.Test;

import java.util.HashMap;
import java.util.Map;

import io.confluent.connect.replicator.util.Utils;

import static org.junit.Assert.assertEquals;

public class ReplicatorSourceConnectorConfigTest {

  private static Map<String, String> createDefaults() {
    Map<String, String> props = new HashMap<>();
    props.put("src.zookeeper.connect", "foo:2181");
    props.put("src.kafka.bootstrap.servers", "foo:9092");
    props.put("dest.zookeeper.connect", "bar:2181");
    return props;
  }

  @Test
  public void testCollectConsumerConfigs() {
    Map<String, String> props = createDefaults();
    props.put("src.consumer.max.poll.records", "200");

    ReplicatorSourceConnectorConfig config = new ReplicatorSourceConnectorConfig(props);
    Map<String, ?> consumerConfigs = config.getSourceConsumerConfigs();
    assertEquals("200", consumerConfigs.get("max.poll.records"));
  }

  @Test
  public void testDefaultTopicRenameFormat() {
    ReplicatorSourceConnectorConfig config = new ReplicatorSourceConnectorConfig(createDefaults());
    assertEquals("foo", Utils.renameTopic(config.getTopicRenameFormat(), "foo"));
  }

  @Test
  public void testDefaultTimestampType() {
    ReplicatorSourceConnectorConfig config = new ReplicatorSourceConnectorConfig(createDefaults());
    assertEquals(TimestampType.CREATE_TIME.toString(), config.getTopicTimestampType());
  }

  @Test(expected = ConfigException.class)
  public void testInvalidLicense() {
    final Map<String, String> defaults = createDefaults();
    defaults.put("confluent.license", "magic");
    new ReplicatorSourceConnectorConfig(defaults);
  }

}
