// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.connect.replicator;

import org.apache.kafka.clients.CommonClientConfigs;
import org.apache.kafka.clients.consumer.internals.PartitionAssignor;
import org.apache.kafka.common.TopicPartition;
import org.easymock.EasyMockSupport;
import org.junit.Test;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static java.util.Collections.singletonList;
import static org.easymock.EasyMock.expect;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;

public class ReplicatorSourceConnectorTest extends EasyMockSupport {

  @Test
  public void testVersion() {
    ReplicatorSourceConnectorConfig config = createMock(ReplicatorSourceConnectorConfig.class);
    TopicMonitorThread monitorThread = createMock(TopicMonitorThread.class);
    String version = new ReplicatorSourceConnector(config, monitorThread).version();
    assertNotNull(version);
    assertFalse(version.isEmpty());
  }

  @Test
  public void testTaskConfigs() {
    String topic = "topic";
    int maxTasks = 2;

    ReplicatorSourceConnectorConfig config = createMock(ReplicatorSourceConnectorConfig.class);
    TopicMonitorThread monitorThread = createMock(TopicMonitorThread.class);

    HashMap<String, String> configOriginals = new HashMap<>();
    configOriginals.put(SourceKafkaConfigs.PREFIX + CommonClientConfigs.BOOTSTRAP_SERVERS_CONFIG, "localhost:9092");
    configOriginals.put(ReplicatorSourceConnectorConfig.DST_ZOOKEEPER_CONNECT_CONFIG, "localhost:2181");
    configOriginals.put(ReplicatorSourceConnectorConfig.SRC_ZOOKEEPER_CONNECT_CONFIG, "localhost:2182");
    configOriginals.put(ReplicatorSourceConnectorConfig.TOPIC_REGEX_CONFIG, ".*");
    expect(config.originalsStrings()).andStubReturn(configOriginals);

    Map<String, PartitionAssignor.Assignment> assignments = new HashMap<>();
    List<TopicPartition> assignment1 = singletonList(new TopicPartition(topic, 0));
    List<TopicPartition> assignment2 = singletonList(new TopicPartition(topic, 1));

    assignments.put("task1", new PartitionAssignor.Assignment(assignment1));
    assignments.put("task2", new PartitionAssignor.Assignment(assignment2));

    expect(monitorThread.assignments(maxTasks)).andReturn(assignments);

    replayAll();

    ReplicatorSourceConnector connector = new ReplicatorSourceConnector(config, monitorThread);
    List<Map<String, String>> taskConfigs = connector.taskConfigs(maxTasks);

    assertEquals(2, taskConfigs.size());

    ReplicatorSourceTaskConfig config1 = new ReplicatorSourceTaskConfig(taskConfigs.get(0));
    assertEquals(assignment1, config1.getPartitionAssignment().partitions());
    assertEquals("task1", config1.getTaskId());

    ReplicatorSourceTaskConfig config2 = new ReplicatorSourceTaskConfig(taskConfigs.get(1));
    assertEquals(assignment2, config2.getPartitionAssignment().partitions());
    assertEquals("task2", config2.getTaskId());

    verifyAll();
  }

}