// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.connect.replicator.util;

import org.apache.kafka.connect.data.Schema;
import org.apache.kafka.connect.data.SchemaAndValue;
import org.apache.kafka.connect.errors.DataException;
import org.junit.Test;

import java.nio.charset.StandardCharsets;
import java.util.Arrays;

import static org.junit.Assert.*;

public class ByteArrayConverterTest {
  private static final String TOPIC = "topic";
  private static final byte[] SAMPLE_BYTES = "sample string".getBytes(StandardCharsets.UTF_8);

  private ByteArrayConverter converter = new ByteArrayConverter();

  @Test
  public void testBytesToBytes() {
    assertArrayEquals(
        SAMPLE_BYTES,
        converter.fromConnectData(TOPIC, Schema.BYTES_SCHEMA, SAMPLE_BYTES)
    );
  }

  @Test
  public void testToBytesIgnoresSchema() {
    assertArrayEquals(
        SAMPLE_BYTES,
        converter.fromConnectData(TOPIC, null, SAMPLE_BYTES)
    );
  }

  @Test(expected=DataException.class)
  public void testNonByteArrayToBytes() {
    // Thread class is used here as an improbable candidate for future serialization support.
    converter.fromConnectData(TOPIC, Schema.BYTES_SCHEMA, new Thread());
  }

  @Test
  public void testNullToBytes() {
    assertEquals(null, converter.fromConnectData(TOPIC, Schema.BYTES_SCHEMA, null));
  }

  @Test
  public void testBytesToString() {
    SchemaAndValue data = converter.toConnectData(TOPIC, SAMPLE_BYTES);
    assertEquals(Schema.OPTIONAL_BYTES_SCHEMA, data.schema());
    assertTrue(Arrays.equals(SAMPLE_BYTES, (byte[]) data.value()));
  }

  @Test
  public void testBytesNullToString() {
    SchemaAndValue data = converter.toConnectData(TOPIC, null);
    assertEquals(Schema.OPTIONAL_BYTES_SCHEMA, data.schema());
    assertEquals(null, data.value());
  }
}
