// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.connect.replicator.util;

import org.jose4j.lang.JoseException;
import org.junit.Test;

import java.security.KeyPair;
import java.security.KeyPairGenerator;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.util.concurrent.TimeUnit;

import io.confluent.license.License;

public class LicenseValidationTest {

  public static final KeyPair KEYPAIR = generateKeyPair();

  public static String generateLicense() {
    return generateLicense(System.currentTimeMillis() + TimeUnit.DAYS.toMillis(365));
  }

  public static String generateLicense(long expiryMs) {
    try {
      return License.sign(KEYPAIR.getPrivate(), "CP Replicator Test", expiryMs, true);
    } catch (JoseException e) {
      throw new RuntimeException(e);
    }
  }

  private static KeyPair generateKeyPair() {
    final KeyPairGenerator keyGen;
    try {
      keyGen = KeyPairGenerator.getInstance("RSA");
      keyGen.initialize(2048, SecureRandom.getInstance("SHA1PRNG"));
    } catch (NoSuchAlgorithmException e) {
      throw new RuntimeException(e);
    }
    return keyGen.generateKeyPair();
  }

  @Test(expected = LicenseValidation.Failure.class)
  public void invalidLicense() throws LicenseValidation.Failure {
    LicenseValidation.verify(KEYPAIR.getPublic(), "fake");
  }

  @Test
  public void validLicense() throws LicenseValidation.Failure {
    LicenseValidation.verify(KEYPAIR.getPublic(), generateLicense());
  }

  @Test(expected = LicenseValidation.Failure.class)
  public void expiredLicense() throws LicenseValidation.Failure {
    LicenseValidation.verify(KEYPAIR.getPublic(), generateLicense(System.currentTimeMillis() - TimeUnit.HOURS.toMillis(1)));
  }

}
