// (Copyright) [2016 - 2016] Confluent, Inc.
package io.confluent.connect.replicator.util;

import org.apache.curator.test.TestingServer;
import org.easymock.EasyMockSupport;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import kafka.utils.ZkUtils;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class TrialPeriodTest extends EasyMockSupport {

  private TestingServer zkServer;
  private ZkUtils zkUtils;

  @Before
  public void startup() throws Exception {
    zkServer = new TestingServer();
    zkUtils = ZkUtils.apply(zkServer.getConnectString(), 6000, 10000, false);
  }

  @After
  public void shutdown() throws Exception {
    if (zkUtils != null) {
      zkUtils.close();
    }
    if (zkServer != null) {
      zkServer.close();
    }
  }

  @Test
  public void startOrVerify() {
    // Clean slate
    assertFalse(zkUtils.pathExists(TrialPeriod.ZK_PATH));

    // Start trial
    assertTrue(TrialPeriod.startOrVerify(System.currentTimeMillis(), zkUtils));
    assertTrue(zkUtils.pathExists(TrialPeriod.ZK_PATH));

    // Trial still valid
    assertTrue(TrialPeriod.startOrVerify(System.currentTimeMillis(), zkUtils));

    // Trial invalid
    assertFalse(TrialPeriod.startOrVerify(System.currentTimeMillis() + TrialPeriod.TRIAL_LIMIT_MILLIS, zkUtils));
  }

}
